@@ -40,8 +40,9 @@
 #' Uncertainty estimates are available for all predicted quantities using bootstrapping.
 #'
 #' \subsection{New customer prediction}{
-#' The fitted model can also be used to predict the number of transactions a single, average
+#' The fitted model can also be used to predict the number of transactions a fictional, single, average
 #' newly alive customer is expected to make at the moment of the first transaction ("coming alive").
+#' This is, for a customer which has no existing order history.
 #' For covariate models, the prediction is for an average customer with the given covariates.
 #'
 #' The individual-level unconditional expectation that is also used for the
@@ -75,26 +76,8 @@
 #' To account for time units which are not annual, the continuous rate has to be further adjusted
 #' to delta=ln(1+d)/k, where k are the number of time units in a year.
 #'
-#' @section Uncertainty Estimates:
-#' Bootstrapping is used to provide confidence intervals of all predicted metrics.
-#' These provide an estimate of parameter uncertainty.
-#' To create bootstrapped data, customer ids are sampled with replacement until reaching original
-#' length and all transactions of the sampled customers are used to create a new \code{clv.data} object.
-#' A new model is fit on the bootstrapped data with the exact same specification as used when
-#' fitting \code{object} (incl. start parameters and `optimx.args`) and it is then used to predict on this data.
 #'
-#' It is highly recommended to fit the original model (\code{object}) with a robust optimization
-#' method, such as Nelder-Mead (\code{optimx.args=list(method='Nelder-Mead')}).
-#' This ensures that the model can also be fit on the bootstrapped data.
-#'
-#' All prediction parameters, incl \code{prediction.end} and \code{continuous.discount.factor}, are forwarded
-#' to the prediction on the bootstrapped data.
-#' Per customer, the boundaries of the confidence intervals of each predicted metric are the
-#' sample quantiles (\code{quantile(x, probs=c((1-level)/2, 1-(1-level)/2)}).
-#'
-#' See \link{clv.bootstrapped.apply} to create a custom bootstrapping procedure.
-#'
-
+#' @template template_predict_uncertainty
 #'
 #'
 #' @seealso models to predict transactions: \link{pnbd}, \link{bgnbd}, \link{ggomnbd}.
@@ -168,9 +151,8 @@
 #' # But it works if providing a prediction.end
 #' predict(pnc, prediction.end = 10) # ends on 2016-12-17
 #'
-#'
-#' # Predict num transactions for a newly alive customer
-#' # in the next 3.45 weeks
+#' # Predict the number of transactions a single, fictional, average new
+#' # customer is expected to make in the first 3.45 weeks since coming alive
 #' # See ?newcustomer() for more examples
 #' predict(apparel.pnbd, newdata = newcustomer(num.periods=3.45))
 #'
@@ -186,21 +168,30 @@ predict.clv.fitted.transactions <- function(object, newdata=NULL, prediction.end
                                             continuous.discount.factor=log(1+0.1), uncertainty=c("none", "boots"), level=0.9, num.boots=100, verbose=TRUE, ...){
 
   check_err_msg(check_user_data_emptyellipsis(...))
-  check_err_msg(check_user_data_uncertainty(uncertainty=uncertainty))
-  # match uncertainty to one of the allowed values
-  uncertainty <- match.arg(tolower(uncertainty), choices = c("none", "boots"), several.ok = FALSE)
 
   # The usual prediction unless newdata indicates a new customer prediction (ie newdata=newcustomer())
-  if(is(newdata, "clv.newcustomer.no.cov")){
-    # not other parameters except object and newdata may be given (all others must be missing)
-    if(!all(missing(prediction.end), missing(predict.spending), missing(continuous.discount.factor))){
-      check_err_msg("Parameters prediction.end, predict.spending and continuous.discount.factor may not be specified when predicting for new customers.")
-    }
+  if(is(newdata, "clv.newcustomer.base")){
 
+    # not other parameters except object and newdata may be given (all others must be missing)
+    if(!all(missing(prediction.end),
+            missing(predict.spending),
+            missing(continuous.discount.factor),
+            missing(uncertainty),
+            missing(level),
+            missing(num.boots))){
+      check_err_msg("No other parameters ('prediction.end', 'predict.spending', 'continuous.discount.factor', uncertainty', 'level', 'num.boots') may be specified when predicting for new customers!")
+    }
 
     return(clv.controlflow.predict.new.customer(clv.fitted = object, clv.newcustomer = newdata))
   }
 
+
+  # match uncertainty to one of the allowed values. Only after newdata section
+  # because after match.arg(), missing() is always false
+  check_err_msg(check_user_data_uncertainty(uncertainty=uncertainty))
+  # match uncertainty to one of the allowed values
+  uncertainty <- match.arg(tolower(uncertainty), choices = c("none", "boots"), several.ok = FALSE)
+
   # If it was not explicitly passed in the call, the spending model should only be applied
   #   it there is spending data. Otherwise, predict does not work out-of-the-box for
   #   data object w/o spending
