@@ -1,6 +1,6 @@
 pnbd_dyncov_palive <- function (clv.fitted){
 
-  cbs.x <- rsx <- i.x <- Bksum <- DkT <- Z <- palive <-  NULL
+  cbs.x <- i.x <- Bksum <- DkT <- A1sum <- F1 <- LL <- palive <-  NULL
 
   # Params, not logparams
   r       <- clv.fitted@prediction.params.model[["r"]]
@@ -8,15 +8,14 @@ pnbd_dyncov_palive <- function (clv.fitted){
   s       <- clv.fitted@prediction.params.model[["s"]]
   beta_0  <- clv.fitted@prediction.params.model[["beta"]]
 
-  LLdata <- copy(clv.fitted@LL.data)
-  cbs    <- copy(clv.fitted@cbs)
-
   # write to LLdata for nicer calculation
-  # Z in the notes: F.2 in LL function
-  LLdata[cbs, cbs.x := i.x, on="Id"]
-  LLdata[,    rsx   := s/(r+s+cbs.x)]
+  LLdata <- copy(clv.fitted@LL.data)
+  LLdata[clv.fitted@cbs, cbs.x := i.x, on="Id"]
 
-  LLdata[, palive := 1/((Bksum+alpha_0)^(cbs.x+r) * (DkT+beta_0)^s * rsx * Z + 1)]
+  # Implementation with improved numerical stability using LL rather than the consitutents of the LL
+  # A1sum = log(Akprod)
+  LLdata[, F1 := A1sum + lgamma(r+cbs.x) - lgamma(r) + r * (log(alpha_0) - log(alpha_0 + Bksum)) + cbs.x * (-log(alpha_0 + Bksum)) + s*(log(beta_0) - log(beta_0+DkT))]
+  LLdata[, palive := exp(F1 - LL)]
 
   # return as data.table
   return(LLdata[, c("Id", "palive")])
