@@ -7,21 +7,16 @@
 #include <gsl/gsl_errno.h>
 #include <gsl/gsl_sf_result.h>
 
-Rcpp::List vec_gsl_hyp2f0_e(const RcppGSL::Vector& vA, const RcppGSL::Vector& vB, const RcppGSL::Vector& vZ);
+Rcpp::List vec_gsl_hyp2f0_e(const arma::vec& vA, const arma::vec& vB, const arma::vec& vZ);
 
-Rcpp::List vec_gsl_hyp2f1_e(const RcppGSL::Vector& vA, const RcppGSL::Vector& vB, const RcppGSL::Vector& vC, const RcppGSL::Vector& vZ);
+Rcpp::List vec_gsl_hyp2f1_e(const arma::vec& vA, const arma::vec& vB, const arma::vec& vC, const arma::vec& vZ);
 
 namespace clv{
-// vec_hyp2F1
-//    all inputs as vectors
+
 arma::vec vec_hyp2F1(const arma::vec& vA, const arma::vec& vB, const arma::vec& vC, const arma::vec& vX);
 
 arma::vec vec_x_kummerU(const double a, const double b, const arma::vec& vX);
 
-arma::vec vec_pow(const arma::vec& vA, const arma::vec& vP);
-
-arma::vec vec_fill(const double d, const arma::uword n);
-
 arma::vec vec_lbeta(const arma::vec& a, const double b);
 
 double lbeta(const double a, const double b);
