@@ -95,7 +95,8 @@ arma::vec pnbd_nocov_LL_ind(const arma::vec& vLogparams,
 double pnbd_nocov_LL_sum(const arma::vec& vLogparams,
                          const arma::vec& vX,
                          const arma::vec& vT_x,
-                         const arma::vec& vT_cal);
+                         const arma::vec& vT_cal,
+                         const arma::vec& vN);
 
 arma::vec pnbd_staticcov_LL_ind(const arma::vec& vParams,
                                 const arma::vec& vX,
@@ -108,6 +109,7 @@ double pnbd_staticcov_LL_sum(const arma::vec& vParams,
                              const arma::vec& vX,
                              const arma::vec& vT_x,
                              const arma::vec& vT_cal,
+                             const arma::vec& vN,
                              const arma::mat& mCov_life,
                              const arma::mat& mCov_trans);
 
